%define anolis_release 2

Name:           xfsprogs
Version:        5.10.0
Release:        %{anolis_release}%{?dist}
Summary:        Userspace utilities that manage XFS filesystems

License:        GPL+ and LGPLv2+
URL:            https://xfs.wiki.kernel.org
Source0:        https://www.kernel.org/pub/linux/utils/fs/xfs/xfsprogs/%{name}-%{version}.tar.xz

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  gettext
BuildRequires:  libattr-devel
BuildRequires:  libuuid-devel
BuildRequires:  libedit-devel
BuildRequires:  libblkid-devel
BuildRequires:  libicu
BuildRequires:  lvm2-devel
BuildRequires:  xz
BuildRequires:  inih-devel
Provides:       xfs-cmds
Provides:       xfsprogs-qa-devel
Suggests:       xfsprogs-xfs_scrub
Obsoletes:	xfs-cmds <= %{version}
Obsoletes:	xfsprogs-qa-devel <= %{version}
Conflicts:	xfsdump < 3.0.1

# backport patch from upstream
Patch01:	xfsprogs-5.11.0-mkfs-fix-wrong-inobtcount-usage-error-output.patch
Patch02:	xfsprogs-5.12.0-libxfs-copy-crtime-correctly-now-that-it-s-timespec6.patch
Patch03:	xfsprogs-5.12.0-libxfs-expose-inobtcount-in-xfs-geometry.patch
Patch04:	xfsprogs-5.12.0-libfrog-report-inobtcount-in-geometry.patch
Patch05:	xfsprogs-5.13.0-xfs-remove-the-unused-xfs_icdinode_has_bigtime-helpe.patch
Patch06:	xfsprogs-5.13.0-xfs-rename-struct-xfs_legacy_ictimestamp.patch
Patch07:	xfsprogs-5.13.0-xfs-rename-xfs_ictimestamp_t.patch
Patch08:	xfsprogs-5.18.0-mkfs-don-t-trample-the-gid-set-in-the-protofile.patch
Patch09:	xfsprogs-5.11.0-xfs-refactor-data-device-extent-validation.patch
Patch10:	xfsprogs-5.18.0-mkfs-fix-missing-validation-of-l-size-against-maximu.patch
Patch11:	xfsprogs-5.18.0-mkfs-reduce-internal-log-size-when-log-stripe-units-.patch
Patch12:	xfsprogs-5.18.0-mkfs-don-t-let-internal-logs-bump-the-root-dir-inode.patch
Patch13:	xfsprogs-5.18.0-mkfs-improve-log-extent-validation.patch
Patch14:	xfsprogs-5.18.0-mkfs-round-log-size-down-if-rounding-log-start-up-ca.patch
Patch15:	xfsprogs-5.19.0-mkfs-terminate-getsubopt-arrays-properly.patch
Patch16:	xfsprogs-5.19.0-xfs_repair-ignore-empty-xattr-leaf-blocks.patch

# Begin: Anolis customized patches
Patch1001:	1001-xfsprogs-add-atomic-write-support.patch
# End: Anolis customized patches

%description
A set of commands to use the XFS file system, including mkfs.xfs.

XFS is a high performance journaling file system which originated on
the SGI IRIX platform.  It is completely multithreaded. It can support
large files and large file systems, extended attributes, and variable
block sizes. It is extent based and makes extensive use of Btrees
(directories, extents, and free space) to aid both performance and
scalability.

Refer to the documentation at https://xfs.wiki.kernel.org/ for complete
details.  This implementation is on-disk compatible with the IRIX
version of XFS.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary: XFS filesystem-specific headers
Requires: xfsprogs = %{version}-%{release}
Requires: libuuid-devel

%description devel
xfsprogs-devel contains the header files needed to develop XFS
filesystem-specific programs.

You should install xfsprogs-devel if you want to develop XFS
filesystem-specific programs,  If you install xfsprogs-devel, you'll
also want to install xfsprogs.

%package xfs_scrub
Summary: XFS scrubbing scripts and service files
Group: System/Filesystems
Requires: xfsprogs

%description xfs_scrub
Scripts and systemd service files for background scrubbing of metadata
on xfs filesystems.

%prep
%autosetup -p1

%build
%configure --enable-editline=yes --enable-blkid=yes
%make_build

%install
make install DESTDIR=%{buildroot} install install-dev \
  PKG_ROOT_SBIN_DIR=%{_sbindir} PKG_ROOT_LIB_DIR=%{_libdir}

# nuke .la files, etc
rm -f %{buildroot}/{%{_lib}/*.{la,a,so},%{_libdir}/*.{la,a}}

# remove non-versioned docs location
rm -rf %{buildroot}/%{_datadir}/doc/xfsprogs

%generate_compatibility_deps

rm -rf %{buildroot}/%{abidir}/help

%find_lang %{name}

%files -f %{name}.lang
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/*.dump
%dir %{_usr}/%{_lib}/xfsprogs
%{_usr}/%{_lib}/xfsprogs/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/*
%{_unitdir}/*
%{abidir}/*-option.list
%exclude %{_sbindir}/xfs_scrub*
%exclude %{_mandir}/man8/xfs_scrub*
%exclude %{_usr}/%{_lib}/xfsprogs/xfs_scrub*
%exclude %{_mandir}/man8/xfs_scrub_all*
%exclude %{_unitdir}/xfs_scrub*
%exclude %{abidir}/xfs_scrub*-option.list

%files doc
%doc doc/CHANGES README

%files xfs_scrub
%{_sbindir}/xfs_scrub*
%{_mandir}/man8/xfs_scrub*
%{_usr}/%{_lib}/xfsprogs/xfs_scrub*
%{_mandir}/man8/xfs_scrub_all*
%{_unitdir}/xfs_scrub*
%{abidir}/xfs_scrub*-option.list

%files devel
%{_mandir}/man2/*
%{_mandir}/man3/*
%dir %{_includedir}/xfs
%{_includedir}/xfs/handle.h
%{_includedir}/xfs/jdm.h
%{_includedir}/xfs/linux.h
%{_includedir}/xfs/xfs.h
%{_includedir}/xfs/xfs_arch.h
%{_includedir}/xfs/xfs_fs.h
%{_includedir}/xfs/xfs_fs_compat.h
%{_includedir}/xfs/xfs_types.h
%{_includedir}/xfs/xfs_format.h
%{_includedir}/xfs/xfs_da_format.h
%{_includedir}/xfs/xfs_log_format.h
%{_includedir}/xfs/xqm.h

%{_libdir}/*.so

%changelog
* Tue May 16 2023 Ferry Meng <mengferry@linux.alibaba.com> - 5.10.0-2
- Add mkfs.xfs fixed patches from upstream
- xfs_repair: ignore empty xattr leaf blocks

* Fri Oct 28 2022 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> - 5.10.0-1
- Rollback to 5.10.0
- Add patches cherry-picked from upstream 5.10 to 5.18
- Add Anolis customized atomic write support patches

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.19.0-1
- update to 5.19.0

* Fri Mar 04 2022 Su Lifan <su-lifan@linux.alibaba.com> - 5.14.2-1
- Initial packaging for Anolis OS 23
